@@ -20,18 +20,13 @@
 #include "ui_settings_colors.h"
 #include "ui_settings_gradients.h"
 #include "ui_settings_calc.h"
-#include "elementdataviewer.h"
 #include "detailinfodlg.h"
-#include "molcalcwidget.h"
 #include "detailedgraphicaloverview.h"
 #include "gradientwidget_impl.h"
 #include "kalziumdataobject.h"
-#include "isotopetabledialog.h"
 #include "kalziumnumerationtype.h"
 #include "kalziumschemetype.h"
 #include "kalziumgradienttype.h"
-#include "rsdialog.h"
-#include "tablesdialog.h"
 #include "legendwidget.h"
 #include "exportdialog.h"
 #include "search.h"
@@ -40,8 +35,6 @@
 #include "psetables.h"
 #include <config-kalzium.h>
 
-#include "calculator/calculator.h"
-
 #ifdef HAVE_FACILE
 #include "eqchemview.h"
 #endif
@@ -85,16 +78,21 @@ Kalzium::Kalzium() : KXmlGuiWindow( 0 )
     // adding the libkdeedu catalog
     KGlobal::locale()->insertCatalog( "libkdeedu" );
 
+    // Init pointers with null
+    m_glossarydlg = 0;
+    m_infoDialog = 0;
+    m_isotopeDialog = 0;
+    m_elementDataPlotter = 0;
+    m_tablesDialog = 0;
+    m_rsDialog = 0;
+    m_calculator = 0;
+
     // reading the elements from file
     KalziumDataObject::instance();
 
     Search *newsearch = new Search();
     KalziumDataObject::instance()->setSearch( newsearch );
 
-    m_infoDialog = 0;
-    m_toolboxCurrent = 0;
-    m_exportDialog = 0;
-
     // Main pse-Table Tablewidget
     QWidget *pseTempWidget = new QWidget(this);
     QVBoxLayout *layout = new QVBoxLayout( pseTempWidget );
@@ -126,22 +124,6 @@ Kalzium::Kalzium() : KXmlGuiWindow( 0 )
     setupSidebars();
     setupActions();
 
-    // creating the glossary dialog and loading the glossaries we have
-    m_glossarydlg = new GlossaryDialog( this );
-    m_glossarydlg->setObjectName( QLatin1String( "glossary" ) );
-    QString dir = KGlobal::dirs()->findResourceDir( "data", "kalzium/data/" );
-    QString picturepath = dir + "kalzium/data/bg.jpg";
-    KUrl u = KUrl::fromPath( dir + "kalzium/data/knowledge.xml" );
-    Glossary *g = new Glossary( u );
-    g->setName( i18n( "Knowledge" ) );
-    g->setBackgroundPicture( picturepath );
-    m_glossarydlg->addGlossary( g, true );
-    u = KUrl::fromPath( dir + "kalzium/data/tools.xml" );
-    g = new Glossary( u, dir + "kalzium/data/toolpics/" );
-    g->setName( i18n( "Tools" ) );
-    g->setBackgroundPicture( picturepath );
-    m_glossarydlg->addGlossary( g, true );
-
     setupStatusBar();
 }
 
@@ -330,11 +312,6 @@ void Kalzium::setupSidebars()
 
     m_toolbox->addItem( m_gradientWidget, KIcon( "statematter" ), i18n( "View" ) );
 
-    m_calcWidget = new MolcalcWidget( m_toolbox );
-    m_calcWidget->setObjectName( "molcalcwidget" );
-    m_calcWidget->hideExtra();
-    m_toolbox->addItem( m_calcWidget, KIcon( "calculate" ), i18n( "Calculate" ) );
-
     addDockWidget( Qt::LeftDockWidgetArea, m_dockWin );
     addDockWidget( Qt::BottomDockWidgetArea, m_tableDock, Qt::Horizontal);
     addDockWidget( Qt::BottomDockWidgetArea, m_legendDock, Qt::Horizontal );
@@ -358,14 +335,33 @@ void Kalzium::slotExportTable()
 
 void Kalzium::slotGlossary()
 {
+    if(!m_glossarydlg){
+      // creating the glossary dialog and loading the glossaries we have
+      m_glossarydlg = new GlossaryDialog( this );
+      m_glossarydlg->setObjectName( QLatin1String( "glossary" ) );
+      QString dir = KGlobal::dirs()->findResourceDir( "data", "kalzium/data/" );
+      QString picturepath = dir + "kalzium/data/bg.jpg";
+      KUrl u = KUrl::fromPath( dir + "kalzium/data/knowledge.xml" );
+      Glossary *g = new Glossary( u );
+      g->setName( i18n( "Knowledge" ) );
+      g->setBackgroundPicture( picturepath );
+      m_glossarydlg->addGlossary( g, true );
+      u = KUrl::fromPath( dir + "kalzium/data/tools.xml" );
+      g = new Glossary( u, dir + "kalzium/data/toolpics/" );
+      g->setName( i18n( "Tools" ) );
+      g->setBackgroundPicture( picturepath );
+      m_glossarydlg->addGlossary( g, true );
+    }
+
     m_glossarydlg->show();
 }
 
 void Kalzium::slotRS()
 {
-    RSDialog *rs = new RSDialog( this );
-    rs->setAttribute(Qt::WA_DeleteOnClose);
-    rs->show();
+    if(!m_rsDialog){
+      m_rsDialog = new RSDialog( this );
+    }
+    m_rsDialog->show();
 }
 
 void Kalzium::slotOBConverter()
@@ -377,17 +373,18 @@ void Kalzium::slotOBConverter()
 #endif
 }
 
-void Kalzium::slotMoleculeviewer()
+MoleculeDialog *Kalzium::slotMoleculeviewer()
 {
 #if defined(HAVE_OPENBABEL2) && defined(HAVE_EIGEN) && defined(HAVE_AVOGADRO)
 
     if (!QGLFormat::hasOpenGL()) {
         KMessageBox::error(0, i18n("This system does not support OpenGL."), i18n("Kalzium Error"));
-        return;
+        return NULL;
     }
 
     MoleculeDialog * d = new MoleculeDialog( this );
     d->show();
+    return d;
 
 #if 0
     KPluginLoader loader("libkalziumglpart" );
@@ -401,34 +398,39 @@ void Kalzium::slotMoleculeviewer()
     }
 #endif
 #endif
+    return NULL;
 }
 
 void Kalzium::slotTables()
 {
-    TablesDialog *t = new TablesDialog( this );
-    t->setAttribute(Qt::WA_DeleteOnClose);
-    t->show();
+    if(!m_tablesDialog){
+      m_tablesDialog = new TablesDialog( this );
+    }
+    m_tablesDialog->show();
 }
 
 void Kalzium::slotIsotopeTable()
 {
-    IsotopeTableDialog *ndialog = new IsotopeTableDialog( this );
-    ndialog->setAttribute(Qt::WA_DeleteOnClose);
-    ndialog->show();
+   if(!m_isotopeDialog){
+     m_isotopeDialog = new IsotopeTableDialog( this );
+   }
+   m_isotopeDialog->show();
 }
 
 void Kalzium::slotPlotData()
 {
-    ElementDataViewer *edw = new ElementDataViewer( this );
-    edw->setAttribute(Qt::WA_DeleteOnClose);
-    edw->show();
+    if(!m_elementDataPlotter){
+      m_elementDataPlotter = new ElementDataViewer( this );
+    }
+    m_elementDataPlotter->show();
 }
 
 void Kalzium::showCalculator()
 {
-    calculator *Cal = new calculator ( this );
-    Cal->setAttribute(Qt::WA_DeleteOnClose);
-    Cal -> show();
+    if(!m_calculator){
+      m_calculator = new calculator ( this );
+    }
+    m_calculator -> show();
 }
 
 void Kalzium::slotSwitchtoTable( int index )
@@ -630,6 +632,16 @@ Kalzium::~Kalzium()
     delete m_tableDock;
 }
 
+void Kalzium::loadMolecule(const QString &moleculeFile)
+{
+#if defined(HAVE_OPENBABEL2) && defined(HAVE_EIGEN) && defined(HAVE_AVOGADRO)
+    MoleculeDialog *d = slotMoleculeviewer ();
+    if (d) {
+        d->loadMolecule(moleculeFile);
+    }
+#endif
+}
+
 QSize Kalzium::sizeHint() const
 {
     return QSize(700, 500);
